"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
const fs = require("fs");
const glob = require("glob");
const path = require("path");
const format = require("string-format");
const i18n_constants_1 = require("../i18n.constants");
let I18nService = class I18nService {
    constructor(i18nOptions) {
        this.i18nOptions = i18nOptions;
        this.translations = {};
        this.logger = new common_1.Logger('I18nService');
        if (!fs.existsSync(this.i18nOptions.path)) {
            this.logger.error('i18n path does not exists');
        }
        glob(this.i18nOptions.path + '**/*.json', (err, files) => {
            files.map(file => {
                const key = path.parse(file).name;
                const data = JSON.parse(fs.readFileSync(file, 'utf8'));
                for (const property of Object.keys(data)) {
                    this.translations[key] = !!this.translations[key]
                        ? this.translations[key]
                        : {};
                    if (!!this.translations[key][property]) {
                        this.logger.error(`translation "${property}" already exists in language "${key}", change key from file: ${file}`);
                        return;
                    }
                    this.translations[key][property] = data[property];
                }
            });
            this.logger.log('Translation files setup');
        });
    }
    translate(lang, key, args = []) {
        try {
            let translation = this.translations[lang][key];
            if (translation === undefined || translation === null) {
                const message = `translation "${key}" in "${lang}" doesn't exist.`;
                this.logger.error(message);
                if (this.i18nOptions.fallbackLanguage !== null || this.i18nOptions.fallbackLanguage !== undefined && lang !== this.i18nOptions.fallbackLanguage) {
                    return this.translate(this.i18nOptions.fallbackLanguage, key, args);
                }
                else {
                    return message;
                }
            }
            if (args && args.length > 0) {
                translation = format(translation, ...(args || []));
            }
            return translation;
        }
        catch (e) {
            return e.message;
        }
    }
};
I18nService = __decorate([
    common_1.Injectable(),
    __param(0, common_1.Inject(i18n_constants_1.I18N_OPTIONS)),
    __metadata("design:paramtypes", [Object])
], I18nService);
exports.I18nService = I18nService;
